/**
 * Copyright (C) 2009-2011 enStratusNetworks LLC
 *
 * ====================================================================
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * ====================================================================
 */

package org.dasein.cloud.admin;

import java.util.Collection;
import java.util.Locale;

import org.dasein.cloud.CloudException;
import org.dasein.cloud.InternalException;

/**
 * <p>
 *  Provides interaction with the pricing and billing mechanics for the cloud. An application
 *  can leverage this service to determine pricing for components it is managing.
 * </p>
 * <p>
 * Last modified $Date$
 * </p>
 * @version $Revision$
 * @author George Reese
 */
public interface PrepaymentSupport {
        public Offering getOffering(String offeringId) throws InternalException, CloudException;
    
    public Prepayment getPrepayment(String prepaymentId) throws InternalException, CloudException;
    
    public String getProviderTermForOffering(Locale locale);
    
    public String getProviderTermForPrepayment(Locale locale);
        
    public Collection<Offering> listOfferings() throws InternalException, CloudException;

    public Collection<Prepayment> listPrepayments() throws InternalException, CloudException;
    
    public String prepay(String offeringId, int count) throws InternalException, CloudException;
}
