/**
 * Copyright (C) 2009-2011 enStratusNetworks LLC
 *
 * ====================================================================
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * ====================================================================
 */

package org.dasein.cloud.network;

import java.io.Serializable;

/**
 * <p>
 * Represents a firewill with a list of positive access rules.
 * </p>
 * @author George Reese @ enStratus (http://www.enstratus.com)
 */
public class Firewall implements Serializable {
    private static final long serialVersionUID = 5863221134243831750L;
    
    private boolean active;
    private boolean available;
    private String  description;
    private String  name;
    private String  providerFirewallId;
    private String  providerVlanId;
    private String  regionId;
    
    /**
     * Empty constructor for marshalling.
     */
    public Firewall() { }

    /**
     * @return the user-friendly name for the firewall
     */
    public String getName() {
        return name;
    }

    /**
     * @return the cloud-specific unique identifier for this firewall
     */
    public String getProviderFirewallId() {
        return providerFirewallId;
    }

    /**
     * @return the unique region ID of the region in which this firewall operates 
     */
    public String getRegionId() {
        return regionId;
    }


    /**
     * @return <code>true</code> if the firewall is currently active
     */
    public boolean isActive() {
        return active;
    }

    /**
     * @return <code>true</code> if the firewall is currently functioning properly
     */
    public boolean isAvailable() {
        return available;
    }

    /**
     * Sets the current firewall active state.
     * @param active <code>true</code> if the firewall is currently active
     */
    public void setActive(boolean active) {
        this.active = active;
    }

    /**
     * Sets the firewall availability.
     * @param available <code>true</code> if the firewall is currently operating properly
     */
    public void setAvailable(boolean available) {
        this.available = available;
    }

    /**
     * Sets the firewall name.
     * @param name the user-friendly name for the firewall
     */
    public void setName(String name) {
        this.name = name;
    }

    /**
     * Sets the unique ID for the firewall.
     * @param providerFirewallId the cloud-specific unique ID for this firewall
     */
    public void setProviderFirewallId(String providerFirewallId) {
        this.providerFirewallId = providerFirewallId;
    }

    /**
     * Sets the region ID for the region in which the firewall is located.
     * @param regionId the unique region ID for the firewall region
     */
    public void setRegionId(String regionId) {
        this.regionId = regionId;
    }

    /**
     * Provides a long description of the underlying firewall that ideally describes why the
     * firewall exists.
     * @return a long description of the firewall
     */
	public String getDescription() {
		return description;
	}

	/**
	 * Defines the firewall description.
	 * @param description a description of the firewall
	 */
	public void setDescription(String description) {
		this.description = description;
	}

    public void setProviderVlanId(String providerVlanId) {
        this.providerVlanId = providerVlanId;
    }

    public String getProviderVlanId() {
        return providerVlanId;
    }
}
