/**
 * Copyright (C) 2009-2011 enStratusNetworks LLC
 *
 * ====================================================================
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * ====================================================================
 */

package org.dasein.cloud.network;

import org.dasein.cloud.CloudException;
import org.dasein.cloud.InternalException;

public interface VPNSupport {
    public abstract void attachToVLAN(String providerVpnId, String providerVlanId) throws CloudException, InternalException;
    
    public abstract void connectToGateway(String providerVpnId, String toGatewayId) throws CloudException, InternalException;
    
    public abstract VPN createVPN(String inProviderDataCenterId, String name, String description, VPNProtocol protocol) throws CloudException, InternalException;
    
    public abstract VPNGateway createVPNGateway(String endpoint, String name, String description, VPNProtocol protocol, String bgpAsn) throws CloudException, InternalException;
    
    public abstract void deleteVPN(String providerVpnId) throws CloudException, InternalException;
    
    public abstract void deleteVPNGateway(String providerVPNGatewayId) throws CloudException, InternalException;
    
    public abstract void detachFromVLAN(String providerVpnId, String providerVlanId) throws CloudException, InternalException;
    
    public abstract void disconnectFromGateway(String providerVpnId) throws CloudException, InternalException;
    
    public abstract VPN getVPN(String providerVpnId) throws CloudException, InternalException;
    
    public abstract Iterable<VPN> listVPNs() throws CloudException, InternalException;
    
    public abstract boolean isSubscribed() throws CloudException, InternalException;
}
